# 023

|                                                         | Oven type 1         |
|:--------------------------------------------------------|:--------------------|
| bindTime                                                | 1652967068476       |
| createTime                                              | 0                   |
| deviceFeatureCode                                       | 295608422d362be1    |
| deviceFeatureName                                       | OVEN                |
| deviceId                                                | <redacted>          |
| deviceNickName                                          | Atag Oven           |
| deviceTypeCode                                          | 023                 |
| deviceTypeName                                          |                     |
| offlineState                                            | 1                   |
| puid                                                    | <redacted>          |
| role                                                    | 1                   |
| roomId                                                  | 144011              |
| roomName                                                | cap lab             |
| seq                                                     | 0                   |
| statusList.Alarm_alarm_time_reached                     | 0                   |
| statusList.Alarm_baking_finished                        | 0                   |
| statusList.Alarm_descale_now                            | 0                   |
| statusList.Alarm_preheat_reached                        | 0                   |
| statusList.Alarm_steam_empty                            | 0                   |
| statusList.Alarm_temperature_reached                    | 0                   |
| statusList.Alarm_turn_food                              | 0                   |
| statusList.Alarm_warning_fastpreheat                    | 0                   |
| statusList.Alarm_warning_microwave                      | 0                   |
| statusList.Alarm_warning_steam                          | 0                   |
| statusList.Alarm_water_tank_empty                       | 0                   |
| statusList.Alarm_water_tank_missing                     | 0                   |
| statusList.Bake_start_utc_datetime_bdc_timestamp        | 2024/5/8T11:8:55    |
| statusList.Baking_start_time_hour                       | 0                   |
| statusList.Baking_start_time_minute                     | 0                   |
| statusList.CURRENT_SET_STEP                             | 3162                |
| statusList.Child_lock                                   | 3191                |
| statusList.Current_baking_step                          | 3252                |
| statusList.Delay_start_status                           | 0                   |
| statusList.Demo_mode                                    | 3296                |
| statusList.Device_status                                | 3011                |
| statusList.Door                                         | 3041                |
| statusList.Hard_pairing_status                          | 9106                |
| statusList.Light                                        | 3036                |
| statusList.Meat_probe_measured_temperature              | 0                   |
| statusList.Meat_probe_set_temperature                   | 0                   |
| statusList.Oven_temperature                             | 45                  |
| statusList.Preheat                                      | 0                   |
| statusList.Remote_control_mode                          | 2                   |
| statusList.Sand_timer1_duration_in_seconds              | 0                   |
| statusList.Sand_timer1_start_utc_datetime_bdc_timestamp | 2024/1/24T14:50:59  |
| statusList.Sand_timer1_status                           | 1                   |
| statusList.Sand_timer2_duration_in_seconds              | 0                   |
| statusList.Sand_timer2_start_utc_datetime_bdc_timestamp | 2023/12/13T11:34:47 |
| statusList.Sand_timer2_status                           | 1                   |
| statusList.Sand_timer3_duration_in_seconds              | 0                   |
| statusList.Sand_timer3_start_utc_datetime_bdc_timestamp | 2023/12/13T11:35:2  |
| statusList.Sand_timer3_status                           | 1                   |
| statusList.Set_progress_type                            | 3401                |
| statusList.Status                                       | 3011                |
| statusList.Step1_duration                               | 30                  |
| statusList.Step1_heater_system                          | 3081                |
| statusList.Step1_remaining_time                         | 7                   |
| statusList.Step1_set_temperature                        | 180                 |
| statusList.Step1_status                                 | 0                   |
| statusList.Step2_duration                               | 6                   |
| statusList.Step2_heater_system                          | 3097                |
| statusList.Step2_remaining_time                         | 3                   |
| statusList.Step2_set_temperature                        | 139                 |
| statusList.Step2_status                                 | 0                   |
| statusList.Step3_duration                               | 30                  |
| statusList.Step3_heater_system                          | 3110                |
| statusList.Step3_remaining_time                         | 1                   |
| statusList.Step3_set_temperature                        | 100                 |
| statusList.Step3_status                                 | 0                   |
| statusList.Total_passed_time                            | 2                   |
| statusList.Total_remaining_time                         | 0                   |
| statusList.daily_energy_kwh                             | 0                   |
| useTime                                                 | 0                   |
| wifiId                                                  | <redacted>          |

## Generated from

- [`Oven_type_1.json`](Oven_type_1.json)
